pub enum RiRequestSlaClass {
Critical,
High,
Medium,
Low,
}Expand description
SLA class for a resource request.
This enum describes the service level expectations for a request. Schedulers can use this information to trade off between latency, availability, and resource usage.
Variants
Critical
Mission critical requests that should be served with the highest priority
High
High priority requests
Medium
Normal priority requests
Low
Low priority / best-effort requests